==> blanco.plugin.stringgroup_0.1.1-src.zip: blancoStringGroupPlugin/blanco/main/blanco/plugin/stringgroup/wizards/AbstractBlancoStringGroupWizardPage.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.plugin.stringgroup.wizards;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.stringgroup.BlancoStringGroupPluginConstants;

/**
 */
public abstract class AbstractBlancoStringGroupWizardPage extends WizardPage {
    /**
     */
    private Label labelMessage1;

    /**
     */
    private Label labelMessage2;

    /**
     */
    private ISelection selection;

    /**
     *
     * @param selection
     */
    public AbstractBlancoStringGroupWizardPage(final ISelection selection) {
        super("wizardPage");
        setTitle("blancoStringGroup vOC pxEBU[h");
        this.selection = selection;
    }

    /**
     *
     * @param parent
     */
    public void createControl(final Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText("blancoStringGroup Wizardւ悤I");
        new Label(container, SWT.NONE).setText("̃EBU[hblancoStringGroupvOCp\ɂȂ܂ł̎菇`܂B");
        new Label(container, SWT.NONE).setText("");
        new Label(container, SWT.NONE).setText("̃EBU[h̎傽ړÍAݒt@C(" + BlancoStringGroupPluginConstants.TARGET_FILENAME + ")vWFNg̃[gtH_ɍ쐬邱ƂłB");
        new Label(container, SWT.NONE).setText("ݒt@C(" + BlancoStringGroupPluginConstants.TARGET_FILENAME + ")Ɋւ󋵂͉L̂悤ɂȂĂ܂B");

        labelMessage1 = new Label(container, SWT.NONE);
        labelMessage1.setText("  1.vWFNg̃[gtH_ " + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@CVKɍ쐬܂B");
        labelMessage2 = new Label(container, SWT.NONE);
        labelMessage2.setText("  2.EBU[h(Finish)sƂɂVK" + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@C쐬ĕҏWsƂł܂B");

        setControl(container);

        IProject proj = BlancoStringGroupWizard.getProject(selection);
        if (proj == null) {
            setErrorMessage("vWFNgIł");
            setPageComplete(false);
            labelMessage1.setText("  1.vWFNgIĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        if (proj.isOpen() == false) {
            setPageComplete(false);
            setErrorMessage("JĂvWFNgIĂAēxEBU[hsĂB");
            labelMessage1.setText("  1.IꂽvWFNg͊JĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        IFile file = proj.getFile(BlancoStringGroupPluginConstants.TARGET_FILENAME);
        if (file.exists()) {
            labelMessage1.setText("  1.ɃvWFNg̃[g " + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@C݂Ă܂B");
            labelMessage2.setText("  2.EBU[h(Finish)sƂɂ" + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@C̕ҏWsƂł܂B");
        }
    }
}

==> blanco.plugin.stringgroup_0.3.2-src.zip: blancoStringGroupPlugin/blanco/main/blanco/plugin/stringgroup/wizards/AbstractBlancoStringGroupWizardPage.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 */
package blanco.plugin.stringgroup.wizards;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

import blanco.plugin.stringgroup.BlancoStringGroupPluginConstants;

/**
 */
public abstract class AbstractBlancoStringGroupWizardPage extends WizardPage {
    /**
     */
    private Label labelMessage1;

    /**
     */
    private Label labelMessage2;

    /**
     */
    protected ISelection selection;

    /**
     *
     * @param selection
     */
    public AbstractBlancoStringGroupWizardPage(final ISelection selection) {
        super("wizardPage");
        setTitle("blancoStringGroup vOC pxEBU[h");
        this.selection = selection;
    }

    /**
     *
     * @param parent
     */
    public void createControl(final Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE).setText("blancoStringGroup Wizardւ悤I");
        new Label(container, SWT.NONE).setText("̃EBU[hblancoStringGroupvOCp\ɂȂ܂ł̎菇`܂B");
        new Label(container, SWT.NONE).setText("");
        new Label(container, SWT.NONE).setText("̃EBU[h̎傽ړÍAݒt@C(" + BlancoStringGroupPluginConstants.TARGET_FILENAME + ")vWFNg̃[gtH_ɍ쐬邱ƂłB");
        new Label(container, SWT.NONE).setText("ݒt@C(" + BlancoStringGroupPluginConstants.TARGET_FILENAME + ")Ɋւ󋵂͉L̂悤ɂȂĂ܂B");

        labelMessage1 = new Label(container, SWT.NONE);
        labelMessage1.setText("  1.vWFNg̃[gtH_ " + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@CVKɍ쐬܂B");
        labelMessage2 = new Label(container, SWT.NONE);
        labelMessage2.setText("  2.EBU[h(Finish)sƂɂVK" + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@C쐬ĕҏWsƂł܂B");

        setControl(container);

        IProject proj = BlancoStringGroupWizard.getProject(selection);
        if (proj == null) {
            setErrorMessage("vWFNgIł");
            setPageComplete(false);
            labelMessage1.setText("  1.vWFNgIĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        if (proj.isOpen() == false) {
            setPageComplete(false);
            setErrorMessage("JĂvWFNgIĂAēxEBU[hsĂB");
            labelMessage1.setText("  1.IꂽvWFNg͊JĂ܂B");
            labelMessage2.setText("  2.vWFNg̒ɂ " + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@C͍쐬ł܂B");
            return;
        }

        IFile file = proj.getFile(BlancoStringGroupPluginConstants.TARGET_FILENAME);
        if (file.exists()) {
            labelMessage1.setText("  1.ɃvWFNg̃[g " + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@C݂Ă܂B");
            labelMessage2.setText("  2.EBU[h(Finish)sƂɂ" + BlancoStringGroupPluginConstants.TARGET_FILENAME + "t@C̕ҏWsƂł܂B");
        }
    }
}
